%define libname        %mklibname %{name}
%define libname_devel  %mklibname %{name} -d

%global __requires_exclude perl\\(Parrot::Pmc2c::.*\\)
%global __provides_exclude perl\\(File::Which\\)

Name:          parrot
Version:       8.1.0
Release:       %mkrel 10

Summary:       Virtual Machine for dynamic languages
License:       Artistic 2.0
Group:         Development/Perl
Url:           http://www.parrot.org/
Source0:       ftp://ftp.parrot.org/pub/parrot/releases/stable/%{version}/%{name}-%{version}.tar.bz2
Patch0:        parrot-5.0.0-bison3.patch
BuildRequires: bison
BuildRequires: gdbm-devel
BuildRequires: gmp-devel
BuildRequires: flex
BuildRequires: libicu-devel
BuildRequires: pkgconfig(ncurses)
BuildRequires: perl-doc
BuildRequires: perl(Pod::Parser)
BuildRequires: readline-devel

%description
Parrot is a virtual machine designed to efficiently compile and execute
bytecode for interpreted languages. Parrot will be the target for the final
Perl 6 compiler, and is already usable as a backend for the Rakudo Perl
6 compiler, as well as a variety of other languages

#--

%package -n %libname
Summary:    Parrot Virtual Machine run time library
Group:      Development/Perl
Provides:   lib%{name} = %{version}-%{release}
Requires:   %{name} >= %{version}-%{release}

%description -n %libname
Run time library for %{name}.

#--

%package -n %{name}-doc
Summary:    Parrot Virtual Machine documentation
BuildArch:	noarch
Group:      Development/Perl

%description -n %{name}-doc
Documentation for %{name}.

#--

%package -n %libname_devel
Summary:    Parrot Virtual Machine development headers and libraries
Group:      Development/Perl
Provides:   %{name}-devel = %{version}-%{release}
Requires:   %libname = %{version}

%description -n %libname_devel
Development files for %{name}.

#--

%package -n %{name}-src
Summary:    Parrot Virtual Machine sources
Group:      Development/Perl
BuildArch:  noarch

%description -n %{name}-src
Sources of %{name}.


%prep
%setup -q
%{__perl} -pi -e 's,"lib/,"%{_lib}/, if (/CONST_STRING\(interp,/)' \
    src/library.c
%{__perl} -pi -e "s,'/usr/lib','%{_libdir}',;s,runtime/lib/,runtime/%{_lib}/," \
    tools/dev/install_files.pl \
    tools/dev/mk_manifest_and_skip.pl

%build
%define _disable_ld_no_undefined 1

%{__perl} Configure.pl \
    --prefix=%{_usr} \
    --libdir=%{_libdir} \
    --sysconfdir=%{_sysconfdir} \
    --infodir=%{_infodir} \
    --mandir=%{_mandir} \
    --cc="%{__cc}" \
    --link="%{__cc} %{ldflags}" \
    --enable-shared \
    --lex=/usr/bin/flex \
    --ldflags='%{ldflags}' \
    --libs='-lcurses -lm -lrt'

%{__sed} -i -e '1 s&nqp&/usr/bin/parrot-nqp&' runtime/parrot/library/YAML/Tiny.pm

# the following Configure.pl flag makes the compile goes boom
    #--optimize="$RPM_OPT_FLAGS -maccumulate-outgoing-args" \
%__make LDFLAGS="%ldflags"
export LD_LIBRARY_PATH=$( pwd )/blib/lib
%__make parrot_utils LDFLAGS="%ldflags"
%__make installable LDFLAGS="%ldflags"
%make_build html

%install
export LD_LIBRARY_PATH=$( pwd )/blib/lib
%make_install

# Drop the docs so rpm can pick them up itself.
rm -rf %{buildroot}%{_docdir}/parrot

# Force permissions on doc directories.
find docs examples -type d -exec chmod 755 {} \;
find docs examples -type f -exec chmod 644 {} \;

# Force permissions on shared libs so they get stripped.
find %{buildroot}%{_libdir} -type f \( -name '*.so' -o -name '*.so.*' \) \
    -exec chmod 755 {} \;

# Force permission on perl-scripts in the "tools" subdirectory
find %{buildroot}%{_libdir}/%{name}/%{version}/tools -type f -name "*.pl" -exec chmod 755 {} \; \
    -exec %{__sed} -i -e '1 s&#! perl&#!/usr/bin/perl&' {} \;

%files
%doc ChangeLog CREDITS PBC_COMPAT PLATFORMS README.pod
%doc RESPONSIBLE_PARTIES TODO
%exclude %{_bindir}/parrot_config
%exclude %{_bindir}/pbc_*
%exclude %{_mandir}/man1/pbc_to_exe.1*
%{_bindir}/*
%{_datadir}/%{name}
%{_mandir}/man1/*

%files -n %{name}-doc
%doc docs examples

%files -n %libname
%{_libdir}/parrot
%{_libdir}/*.so.*

%files -n %libname_devel
%{_bindir}/parrot_config
%{_bindir}/pbc_disassemble
%{_bindir}/pbc_merge
%{_bindir}/pbc_to_exe
%{_bindir}/pbc_dump
%{_mandir}/man1/pbc_to_exe.1*
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/*.a

%files -n %{name}-src
%{_prefix}/src/parrot


%changelog
* Mon Nov 30 2020 luigiwalser <luigiwalser> 8.1.0-10.mga8
+ Revision: 1650913
- rebuild for icu

* Wed Jul 01 2020 wally <wally> 8.1.0-9.mga8
+ Revision: 1601144
- rebuild for icu 67.1

* Sat Apr 04 2020 wally <wally> 8.1.0-8.mga8
+ Revision: 1564486
- rebuild for new icu 66.1

* Tue Feb 18 2020 umeabot <umeabot> 8.1.0-7.mga8
+ Revision: 1542199
- Mageia 8 Mass Rebuild

* Sat Jan 04 2020 luigiwalser <luigiwalser> 8.1.0-6.mga8
+ Revision: 1475997
- rebuild for readline

* Sat Oct 05 2019 daviddavid <daviddavid> 8.1.0-5.mga8
+ Revision: 1449457
- rebuild for new icu 65.1

* Fri Jan 11 2019 daviddavid <daviddavid> 8.1.0-4.mga7
+ Revision: 1354843
- rebuild for new icu
+ luigiwalser <luigiwalser>
- rebuild for icu

* Mon Aug 27 2018 daviddavid <daviddavid> 8.1.0-2.mga7
+ Revision: 1255088
- rebuild for new icu

* Sat Apr 14 2018 kekepower <kekepower> 8.1.0-1.mga7
+ Revision: 1218629
- Update to version 8.1.0

* Fri Dec 29 2017 wally <wally> 5.0.0-10.mga7
+ Revision: 1186998
- rebuild for new icu

* Wed Mar 15 2017 mrambo3501 <mrambo3501> 5.0.0-9.mga6
+ Revision: 1092757
- Rebuild for icu-58.2

* Sat May 14 2016 shlomif <shlomif> 5.0.0-8.mga6
+ Revision: 1015274
- Rebuild for the new UCI (new major)

* Fri Jan 01 2016 luigiwalser <luigiwalser> 5.0.0-7.mga6
+ Revision: 917913
- rebuild for icu

* Fri Jul 24 2015 cjw <cjw> 5.0.0-6.mga6
+ Revision: 856747
- rebuild for icu 55

* Wed Oct 15 2014 umeabot <umeabot> 5.0.0-5.mga5
+ Revision: 748733
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 5.0.0-4.mga5
+ Revision: 683343
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes

* Sat Apr 05 2014 wally <wally> 5.0.0-3.mga5
+ Revision: 611897
- rebuild for new icu

* Mon Oct 21 2013 umeabot <umeabot> 5.0.0-2.mga4
+ Revision: 538040
- Mageia 4 Mass Rebuild

* Sat Sep 28 2013 fwang <fwang> 5.0.0-1.mga4
+ Revision: 488381
- hardcode link command
- update file list
- fix build with bison 3
- new version 5.0.0
- rebuild for icu 52
+ tmb <tmb>
- rebuild for new icu

* Sun May 26 2013 fwang <fwang> 4.6.0-6.mga4
+ Revision: 428000
- rebuild for new icu

* Sun Jan 13 2013 umeabot <umeabot> 4.6.0-5.mga3
+ Revision: 362421
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Nov 09 2012 fwang <fwang> 4.6.0-4.mga3
+ Revision: 316687
- fix ldflags
- use correct ldflags

* Fri Nov 09 2012 fwang <fwang> 4.6.0-3.mga3
+ Revision: 316652
- rebuild for updated icu

* Tue Nov 06 2012 fwang <fwang> 4.6.0-2.mga3
+ Revision: 314783
- rebuild for new icu

* Tue Jul 17 2012 shlomif <shlomif> 4.6.0-1.mga3
+ Revision: 272025
- New version 4.6.0

* Fri Jun 08 2012 shlomif <shlomif> 4.3.0-1.mga3
+ Revision: 257931
- New upstream version - 4.3.0

* Wed May 30 2012 fwang <fwang> 4.0.0-2.mga3
+ Revision: 249634
- rebuild for new icu

* Mon Jan 30 2012 shlomif <shlomif> 4.0.0-1.mga2
+ Revision: 203292
- New version of Parrot - 4.0.0
+ tv <tv>
- new release

* Mon Jun 20 2011 fwang <fwang> 3.4.0-1.mga2
+ Revision: 110373
- disable parallel build for now
- fix linkage and file list
- new version 3.4.0
- rebuild for new icu

* Sat Apr 02 2011 pterjan <pterjan> 3.1.0-2.mga1
+ Revision: 79798
- Remove filerequires on /usr/lib/pkgconfig directory in the lib package

* Thu Mar 03 2011 jquelin <jquelin> 3.1.0-1.mga1
+ Revision: 63324
- adding missing buildrequires:
- adding missing buildrequires:
- update to 3.1.0
- imported package parrot

